summaryrefslogtreecommitdiffstats
path: root/src/verbs.cpp
diff options
context:
space:
mode:
authorNicolas Dufour <nicoduf@yahoo.fr>2010-01-24 17:28:26 +0000
committerJazzyNico <nicoduf@yahoo.fr>2010-01-24 17:28:26 +0000
commitd76e5c04397e2e7b24d19e1e586be0c0711f65b3 (patch)
tree22539991241b2b36830e85e2e3455fa3084b7bb6 /src/verbs.cpp
parentTranslations. inkscape.pot and pos update. POTFILES.in fix. (diff)
downloadinkscape-d76e5c04397e2e7b24d19e1e586be0c0711f65b3.tar.gz
inkscape-d76e5c04397e2e7b24d19e1e586be0c0711f65b3.zip
Adding the Interpolate tutorial in Help>Tutorials
(bzr r9019)
Diffstat (limited to 'src/verbs.cpp')
-rw-r--r--src/verbs.cpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/verbs.cpp b/src/verbs.cpp
index 7c3652b36..421736b7f 100644
--- a/src/verbs.cpp
+++ b/src/verbs.cpp
@@ -1855,8 +1855,8 @@ TutorialVerb::perform(SPAction */*action*/, void *data, void */*pdata*/)
{
switch (reinterpret_cast<std::size_t>(data)) {
case SP_VERB_TUTORIAL_BASIC:
- /* TRANSLATORS: If you have translated the tutorial-basic.svg file to your language,
- then translate this string as "tutorial-basic.LANG.svg" (where LANG is your language
+ /* TRANSLATORS: If you have translated the tutorial-basic.en.svgz file to your language,
+ then translate this string as "tutorial-basic.LANG.svgz" (where LANG is your language
code); otherwise leave as "tutorial-basic.svg". */
sp_help_open_tutorial(NULL, (gpointer)_("tutorial-basic.svg"));
break;
@@ -1876,6 +1876,10 @@ TutorialVerb::perform(SPAction */*action*/, void *data, void */*pdata*/)
// TRANSLATORS: See "tutorial-basic.svg" comment.
sp_help_open_tutorial(NULL, (gpointer)_("tutorial-calligraphy.svg"));
break;
+ case SP_VERB_TUTORIAL_INTERPOLATE:
+ // TRANSLATORS: See "tutorial-basic.svg" comment.
+ sp_help_open_tutorial(NULL, (gpointer)_("tutorial-interpolate.svg"));
+ break;
case SP_VERB_TUTORIAL_DESIGN:
// TRANSLATORS: See "tutorial-basic.svg" comment.
sp_help_open_tutorial(NULL, (gpointer)_("tutorial-elements.svg"));
@@ -2667,6 +2671,8 @@ Verb *Verb::_base_verbs[] = {
N_("Using bitmap tracing"), NULL/*"tutorial_tracing"*/),
new TutorialVerb(SP_VERB_TUTORIAL_CALLIGRAPHY, "TutorialsCalligraphy", N_("Inkscape: _Calligraphy"),
N_("Using the Calligraphy pen tool"), NULL),
+ new TutorialVerb(SP_VERB_TUTORIAL_INTERPOLATE, "TutorialsInterpolate", N_("Inkscape: _Interpolate"),
+ N_("Using the interpolate extension"), NULL/*"tutorial_interpolate"*/),
new TutorialVerb(SP_VERB_TUTORIAL_DESIGN, "TutorialsDesign", N_("_Elements of Design"),
N_("Principles of design in the tutorial form"), NULL/*"tutorial_design"*/),
new TutorialVerb(SP_VERB_TUTORIAL_TIPS, "TutorialsTips", N_("_Tips and Tricks"),